pub enum TenantDataAccessErrorReason {
EmptyKey,
KeyTooLong,
ReservedKey,
ValueTooLong,
InvalidRange,
ReservedRange,
InvalidRangeLimit,
KeyChangingMutation,
}Expand description
A finite reason for rejecting an application key or range.
Variants
EmptyKey
Keys cannot be empty.
KeyTooLong
FoundationDB cannot accept a key above its size limit.
ReservedKey
Kit metadata and FoundationDB system keys are outside application access.
ValueTooLong
FoundationDB cannot accept a value above its size limit.
InvalidRange
A range must have a non-empty, increasing interval.
ReservedRange
A range could read or clear the kit’s metadata keys.
InvalidRangeLimit
Range reads and transaction options must have bounded limits.
KeyChangingMutation
A mutation is prohibited by the transaction policy or key boundary.